@@ -2,19 +2,22 @@ package helpers
 
 import (
 	"errors"
+	"fmt"
 	"os"
-	"rare/pkg/expressions"
-	"rare/pkg/extractor"
-	"rare/pkg/extractor/batchers"
-	"rare/pkg/extractor/dirwalk"
-	"rare/pkg/logger"
-	"rare/pkg/matchers"
-	"rare/pkg/matchers/dissect"
-	"rare/pkg/matchers/fastregex"
 	"runtime"
 	"slices"
 	"strings"
 
+	"github.com/zix99/rare/pkg/expressions"
+	"github.com/zix99/rare/pkg/extractor"
+	"github.com/zix99/rare/pkg/extractor/batchers"
+	"github.com/zix99/rare/pkg/extractor/dirwalk"
+	"github.com/zix99/rare/pkg/extractor/dirwalk/pathmatch"
+	"github.com/zix99/rare/pkg/logger"
+	"github.com/zix99/rare/pkg/matchers"
+	"github.com/zix99/rare/pkg/matchers/dissect"
+	"github.com/zix99/rare/pkg/matchers/fastregex"
+
 	"github.com/urfave/cli/v2"
 )
 
@@ -40,6 +43,7 @@ func BuildBatcherFromArgumentsEx(c *cli.Context, fileglobs ...string) (*batchers
 		followReopen      = c.Bool("reopen")
 		followPoll        = c.Bool("poll")
 		concurrentReaders = c.Int("readers")
+		readersBuffer     = c.Int("readers-buffer")
 		gunzip            = c.Bool("gunzip")
 		batchSize         = c.Int("batch")
 		batchBuffer       = c.Int("batch-buffer")
@@ -51,6 +55,9 @@ func BuildBatcherFromArgumentsEx(c *cli.Context, fileglobs ...string) (*batchers
 	if concurrentReaders < 1 {
 		logger.Fatalf(ExitCodeInvalidUsage, "Must have at least 1 reader")
 	}
+	if readersBuffer < 1 {
+		logger.Fatalf(ExitCodeInvalidUsage, "Reader buffer must be at least 1 byte")
+	}
 	if followPoll && !follow {
 		logger.Fatalf(ExitCodeInvalidUsage, "Follow (-f) must be enabled for --poll")
 	}
@@ -65,16 +72,16 @@ func BuildBatcherFromArgumentsEx(c *cli.Context, fileglobs ...string) (*batchers
 		if follow {
 			logger.Println("Cannot follow a stdin stream, not a file")
 		}
-		return batchers.OpenReaderToChan("<stdin>", os.Stdin, batchSize, batchBuffer), nil
+		return batchers.OpenReaderToChan("<stdin>", os.Stdin, batchSize, batchBuffer, readersBuffer), nil
 	} else if follow { // Read from source file
 		if gunzip {
 			logger.Println("Cannot combine -f and -z")
 		}
 		walker := BuildPathWalkerFromArguments(c)
-		return batchers.TailFilesToChan(walker.Walk(fileglobs...), batchSize, batchBuffer, followReopen, followPoll, followTail), walker
+		return batchers.TailFilesToChan(walker.Walk(fileglobs...), batchSize, batchBuffer, readersBuffer, followReopen, followPoll, followTail), walker
 	} else { // Read (no-follow) source file(s)
 		walker := BuildPathWalkerFromArguments(c)
-		return batchers.OpenFilesToChan(walker.Walk(fileglobs...), gunzip, concurrentReaders, batchSize, batchBuffer), walker
+		return batchers.OpenFilesToChan(walker.Walk(fileglobs...), gunzip, concurrentReaders, batchSize, batchBuffer, readersBuffer), walker
 	}
 }
 
@@ -85,25 +92,27 @@ func BuildPathWalkerFromArguments(c *cli.Context) *dirwalk.Walker {
 		excludeDir = c.StringSlice("exclude-dir")
 	)
 
-	includeSet, err := dirwalk.NewMatchSet(include...)
+	includeSet, err := pathmatch.NewMatchSet(include...)
 	if err != nil {
 		logger.Fatal(ExitCodeInvalidUsage, err)
 	}
 
-	excludeSet, err := dirwalk.NewMatchSet(exclude...)
+	excludeSet, err := pathmatch.NewMatchSet(exclude...)
 	if err != nil {
 		logger.Fatal(ExitCodeInvalidUsage, err)
 	}
 
-	excludeDirSet, err := dirwalk.NewMatchSet(excludeDir...)
+	excludeDirSet, err := pathmatch.NewMatchSet(excludeDir...)
 	if err != nil {
 		logger.Fatal(ExitCodeInvalidUsage, err)
 	}
 
 	return &dirwalk.Walker{
-		Include:         includeSet,
-		Exclude:         excludeSet,
-		ExcludeDir:      excludeDirSet,
+		Filters: pathmatch.PathMatcher{
+			Include:    includeSet,
+			Exclude:    excludeSet,
+			ExcludeDir: excludeDirSet,
+		},
 		Recursive:       c.Bool("recursive"),
 		FollowSymLinks:  c.Bool("follow-symlinks"),
 		ListSymLinks:    c.Bool("read-symlinks"),
@@ -254,26 +263,40 @@ func getExtractorFlags() []cli.Flag {
 			Category: cliCategoryTweaking,
 			Usage:    "Specifies io batching size. Set to 1 for immediate input",
 			Value:    1000,
+			EnvVars:  []string{"RARE_BATCH"},
 		},
 		&cli.IntFlag{
-			Name:     "batch-buffer",
-			Category: cliCategoryTweaking,
-			Usage:    "Specifies how many batches to read-ahead. Impacts memory usage, can improve performance",
-			Value:    workerCount * 2, // Keep 2 batches ready for each worker
+			Name:        "batch-buffer",
+			Category:    cliCategoryTweaking,
+			Usage:       "Specifies how many batches to read-ahead. Impacts memory usage, can improve performance",
+			Value:       workerCount * 2, // Keep 2 batches ready for each worker
+			DefaultText: fmt.Sprintf("workers*2 = %d", workerCount*2),
+			EnvVars:     []string{"RARE_BATCH_BUFFER"},
 		},
 		&cli.IntFlag{
-			Name:     "workers",
-			Aliases:  []string{"w"},
-			Category: cliCategoryTweaking,
-			Usage:    "Set number of data processors",
-			Value:    workerCount,
+			Name:        "workers",
+			Aliases:     []string{"w"},
+			Category:    cliCategoryTweaking,
+			Usage:       "Set number of data processors",
+			Value:       workerCount,
+			DefaultText: fmt.Sprintf("NumCPU/2+1 = %d", workerCount),
+			EnvVars:     []string{"RARE_WORKERS"},
 		},
 		&cli.IntFlag{
 			Name:     "readers",
 			Aliases:  []string{"wr"},
 			Category: cliCategoryTweaking,
 			Usage:    "Sets the number of concurrent readers (Infinite when -f)",
-			Value:    3,
+			Value:    workerCount,
+			EnvVars:  []string{"RARE_READERS"},
+		},
+		&cli.IntFlag{
+			Name:     "readers-buffer",
+			Aliases:  []string{"wrb"},
+			Category: cliCategoryTweaking,
+			Usage:    "How many bytes will be buffered per reader",
+			Value:    512 * 1024,
+			EnvVars:  []string{"RARE_READERS_BUFFER"},
 		},
 	}
 }
