@@ -3,13 +3,14 @@ package helpers
 import (
 	"io"
 	"os"
-	"rare/pkg/extractor"
-	"rare/pkg/extractor/batchers"
-	"rare/pkg/matchers"
-	"rare/pkg/matchers/fastregex"
 	"strings"
 	"testing"
 
+	"github.com/zix99/rare/pkg/extractor"
+	"github.com/zix99/rare/pkg/extractor/batchers"
+	"github.com/zix99/rare/pkg/matchers"
+	"github.com/zix99/rare/pkg/matchers/fastregex"
+
 	"github.com/stretchr/testify/assert"
 )
 
@@ -32,7 +33,7 @@ func (s *VirtualAggregator) ParseErrors() uint64 {
 
 func TestAggregationLoop(t *testing.T) {
 	// Build a real extractor
-	batcher := batchers.OpenReaderToChan("test", io.NopCloser(strings.NewReader(testData)), 1, 1)
+	batcher := batchers.OpenReaderToChan("test", io.NopCloser(strings.NewReader(testData)), 1, 1, 1024)
 	ex, err := extractor.New(batcher.BatchChan(), &extractor.Config{
 		Matcher: matchers.ToFactory(fastregex.MustCompile(`(\d+)`)),
 		Extract: "val:{1}",
