@@ -3,13 +3,14 @@ package cmd
 import (
 	"fmt"
 	"os"
-	"rare/cmd/helpers"
-	"rare/pkg/aggregation"
-	"rare/pkg/aggregation/sorting"
-	"rare/pkg/color"
-	"rare/pkg/csv"
-	"rare/pkg/multiterm"
-	"rare/pkg/multiterm/termrenderers"
+
+	"github.com/zix99/rare/cmd/helpers"
+	"github.com/zix99/rare/pkg/aggregation"
+	"github.com/zix99/rare/pkg/aggregation/sorting"
+	"github.com/zix99/rare/pkg/color"
+	"github.com/zix99/rare/pkg/csv"
+	"github.com/zix99/rare/pkg/multiterm"
+	"github.com/zix99/rare/pkg/multiterm/termrenderers"
 
 	"github.com/urfave/cli/v2"
 )
