@@ -1,10 +1,11 @@
 package exprofiler
 
 import (
-	"rare/pkg/expressions"
-	"rare/pkg/expressions/stdlib"
 	"testing"
 
+	"github.com/zix99/rare/pkg/expressions"
+	"github.com/zix99/rare/pkg/expressions/stdlib"
+
 	"github.com/stretchr/testify/assert"
 )
 
