@@ -2,9 +2,10 @@ package funclib
 
 import (
 	"errors"
-	"rare/pkg/expressions"
 	"testing"
 
+	"github.com/zix99/rare/pkg/expressions"
+
 	"github.com/stretchr/testify/assert"
 )
 
