@@ -42,8 +42,13 @@ func (s *KeyBuilder) Func(name string, f KeyBuilderFunction) {
 	s.functions[name] = f
 }
 
+func (s *KeyBuilder) HasFunc(name string) (has bool) {
+	_, has = s.functions[name]
+	return
+}
+
 // Compile builds a new key-builder, returning error(s) on build issues
-// if the CompiledKeyBuilder is not nil, then something is still useable (albeit may have problems)
+// if the CompiledKeyBuilder is not nil, then something is still usable (albeit may have problems)
 func (s *KeyBuilder) Compile(template string) (*CompiledKeyBuilder, *CompilerErrors) {
 	kb := &CompiledKeyBuilder{
 		stages: make([]KeyBuilderStage, 0),
