@@ -1,7 +1,7 @@
 package batchers
 
 import (
-	"io/ioutil"
+	"io"
 	"strings"
 	"testing"
 
@@ -9,8 +9,8 @@ import (
 )
 
 func TestOpenReaderToChan(t *testing.T) {
-	r := ioutil.NopCloser(strings.NewReader("Hello\nthere\nbob"))
-	b := OpenReaderToChan("src", r, 1, 1)
+	r := io.NopCloser(strings.NewReader("Hello\nthere\nbob"))
+	b := OpenReaderToChan("src", r, 1, 1, 1024)
 
 	b1 := <-b.BatchChan()
 	assert.Equal(t, "src", b1.Source)
