@@ -1,9 +1,10 @@
 package extractor
 
 import (
-	"rare/pkg/expressions"
 	"testing"
 
+	"github.com/zix99/rare/pkg/expressions"
+
 	"github.com/stretchr/testify/assert"
 )
 
