@@ -2,14 +2,15 @@ package termrenderers
 
 import (
 	"io"
-	"rare/pkg/aggregation"
-	"rare/pkg/aggregation/sorting"
-	"rare/pkg/color"
-	"rare/pkg/multiterm"
-	"rare/pkg/multiterm/termformat"
-	"rare/pkg/multiterm/termscaler"
-	"rare/pkg/multiterm/termunicode"
 	"strings"
+
+	"github.com/zix99/rare/pkg/aggregation"
+	"github.com/zix99/rare/pkg/aggregation/sorting"
+	"github.com/zix99/rare/pkg/color"
+	"github.com/zix99/rare/pkg/multiterm"
+	"github.com/zix99/rare/pkg/multiterm/termformat"
+	"github.com/zix99/rare/pkg/multiterm/termscaler"
+	"github.com/zix99/rare/pkg/multiterm/termunicode"
 )
 
 type Heatmap struct {
